@@ -8,7 +8,8 @@ from clio._clio import (
     PUBLISHED_STATUSES,
     DELETED_STATUSES,
     NEW_VERSION_STATUSES,
-    EDITABLE_STATUSES)
+    EDITABLE_STATUSES,
+    ACTUAL_STATUSES)
 
 from clio._clio import (
     ClioError, PublishError, EditError, UpdateError, DeleteError, RevertError)
