@@ -293,7 +293,7 @@ class Model(object):
 
     def revert(self):
         if self.is_archived():
-            raise RevertError("Cannot revert an archived object.")
+            return self # raise RevertError("Cannot revert an archived object.")
         elif self.status == PUBLISHED_UNDER_EDIT:
             return self._version(EDITABLE).revert()
         elif self.status == PUBLISHED_UNDER_UPDATE:
@@ -335,6 +335,7 @@ class Model(object):
             published.status = PUBLISHED_UNDER_UPDATE
             return self
         elif self.status == PUBLISHED:
+            self._revert_related()
             return self
         else:
             raise RevertError(
